SupabaseBundleRow class
Row type from Supabase bundles table.
Constructors
-
SupabaseBundleRow({required String id, required String channel, required bool enabled, required bool shouldForceUpdate, required String fileHash, String? gitCommitHash, String? message, required String platform, String? targetAppVersion, String? fingerprintHash, required String storageUri, Map<
String, Object?> ? metadata, String? manifestStorageUri, String? manifestFileHash, String? assetBaseStorageUri, int? rolloutCohortCount, List<String> ? targetCohorts}) -
const
-
SupabaseBundleRow.fromJson(Map<
String, dynamic> j) -
factory
Properties
- assetBaseStorageUri → String?
-
final
- channel → String
-
final
- enabled → bool
-
final
- fileHash → String
-
final
- fingerprintHash → String?
-
final
- gitCommitHash → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- manifestFileHash → String?
-
final
- manifestStorageUri → String?
-
final
- message → String?
-
final
-
metadata
→ Map<
String, Object?> ? -
final
- platform → String
-
final
- rolloutCohortCount → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldForceUpdate → bool
-
final
- storageUri → String
-
final
- targetAppVersion → String?
-
final
-
targetCohorts
→ List<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited