SupabaseServiceRoleConfig class
Configuration requiring either a service role key or an anon key.
- Implementers
Constructors
- SupabaseServiceRoleConfig({required String supabaseUrl, String? supabaseServiceRoleKey, String? supabaseAnonKey, SupabaseClientFactory? clientFactory})
-
const
Properties
- clientFactory → SupabaseClientFactory?
-
Optional test seam: a factory that builds the SupabaseClientLike used by
the plugin. When omitted, createSupabaseHttpClient is used (REST API).
Mirrors the TS
vi.mock("@supabase/supabase-js")test seam.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supabaseAnonKey → String?
-
final
- supabaseServiceRoleKey → String?
-
final
- supabaseUrl → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveKey(
) → String - Resolve the best available key — service role preferred over anon.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited